@@ -1747,6 +1747,7 @@ glade_design_layout_init (GladeDesignLayout *layout)
   priv->default_context = gtk_style_context_new ();
   gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
   gtk_style_context_set_path (priv->default_context, path);
+  gtk_style_context_add_class (priv->default_context, GTK_STYLE_CLASS_BACKGROUND);
 
   /* setup static member of rectangles */
   priv->east.width = PADDING + OUTLINE_WIDTH;
@@ -1867,6 +1868,21 @@ glade_design_layout_constructor (GType                  type,
   return object;
 }
 
+static void
+glade_design_layout_dispose (GObject *object)
+{
+  GtkWidget *child;
+
+  /* NOTE: Remove child from hierarchy!
+   * This way we ensure gtk_widget_destroy() will not be called on it.
+   * Glade API like glade_widget_get_children() depends on children hierarchy. 
+   */
+  if ((child = gtk_bin_get_child (GTK_BIN (object))))
+    gtk_container_remove (GTK_CONTAINER (object), child);
+
+  G_OBJECT_CLASS (glade_design_layout_parent_class)->dispose (object);
+}
+
 static void
 glade_design_layout_finalize (GObject *object)
 {
@@ -1885,54 +1901,109 @@ glade_design_layout_finalize (GObject *object)
   G_OBJECT_CLASS (glade_design_layout_parent_class)->finalize (object);
 }
 
+static gboolean
+on_drag_icon_draw (GtkWidget *widget, cairo_t *cr, GladeDesignLayout *layout)
+{
+  GtkStyleContext *context = gtk_widget_get_style_context (widget);
+  cairo_pattern_t *gradient;
+  GtkAllocation alloc;
+  gint x, y, w, h;
+  gdouble h2;
+  GdkRGBA bg;
+  
+  gtk_widget_get_allocation (widget, &alloc);
+  x = alloc.x;
+  y = alloc.y;
+  w = alloc.width;
+  h = alloc.height;
+  h2 = h/2.0;
+
+  gtk_style_context_get_background_color (context, GTK_STATE_NORMAL, &bg);
+
+  gradient = cairo_pattern_create_linear (x, y, x, y+h);
+  cairo_pattern_add_color_stop_rgba (gradient, 0, bg.red, bg.green, bg.blue, 0);
+  cairo_pattern_add_color_stop_rgba (gradient, .5, bg.red, bg.green, bg.blue, .8);
+  cairo_pattern_add_color_stop_rgba (gradient, 1, bg.red, bg.green, bg.blue, 0);
+
+  cairo_set_source (cr, gradient);
+  cairo_rectangle (cr, x+h2, y, w-h, h);
+  cairo_fill (cr);
+  cairo_pattern_destroy (gradient);
+
+  gradient = cairo_pattern_create_radial (x+h2, y+h2, 0, x+h2, y+h2, h2);
+  cairo_pattern_add_color_stop_rgba (gradient, 0, bg.red, bg.green, bg.blue, .8);
+  cairo_pattern_add_color_stop_rgba (gradient, 1, bg.red, bg.green, bg.blue, 0);
+
+  cairo_set_source (cr, gradient);
+  cairo_rectangle (cr, x, y, h2, h);
+  cairo_fill (cr);
+
+  cairo_translate (cr, w-h, 0);
+  cairo_set_source (cr, gradient);
+  cairo_rectangle (cr, x+h2, y, h2, h);
+  cairo_fill (cr);
+  
+  cairo_pattern_destroy (gradient);
+
+  return FALSE;
+}
+
+GtkWidget *
+_glade_design_layout_dnd_icon_widget_new (GdkDragContext *context,
+                                          const gchar *icon_name,
+                                          const gchar *description)
+{
+  GtkWidget *window, *box, *label, *icon;
+  GdkScreen *screen;
+  GdkVisual *visual;
+
+  screen = gdk_window_get_screen (gdk_drag_context_get_source_window (context));
+  visual = gdk_screen_get_rgba_visual (screen);
+  window = gtk_window_new (GTK_WINDOW_POPUP);
+  
+  gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_DND);
+  gtk_window_set_screen (GTK_WINDOW (window), screen);
+  gtk_widget_set_visual (window, visual);
+
+  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
+  gtk_container_set_border_width (GTK_CONTAINER (box), 12);
+
+  icon = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON);
+  gtk_widget_set_opacity (icon, .8);
+  
+  label = gtk_label_new (description);
+
+  gtk_box_pack_start (GTK_BOX (box), icon, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), label, FALSE, TRUE, 0);
+
+  gtk_widget_show_all (box);
+  gtk_container_add (GTK_CONTAINER (window), box);
+
+  gtk_widget_set_app_paintable (window, TRUE);
+  g_signal_connect (window, "draw", G_CALLBACK (on_drag_icon_draw), NULL);
+
+  return window;
+}
+
 static void
 glade_design_layout_drag_begin (GtkWidget *widget, GdkDragContext *context)
 {
   GladeDesignLayoutPrivate *priv = GLADE_DESIGN_LAYOUT_PRIVATE (widget);
-  cairo_pattern_t *pattern;
-  cairo_surface_t *surface;
-  GtkAllocation alloc;
-  GtkWidget *window;
-  GdkScreen *screen;
-  cairo_t *cr;
-  gint x, y;
+  GladeWidgetAdaptor *adaptor;
+  GladeWidget *gwidget;
+  const gchar *icon_name;
+  gchar *description;
 
-  gtk_widget_get_allocation (priv->drag_source, &alloc);
+  gwidget = glade_widget_get_from_gobject (priv->drag_source);
+  adaptor = glade_widget_get_adaptor (gwidget);
+  icon_name = glade_widget_adaptor_get_icon_name (adaptor);
+  description = g_strdup_printf ("%s [%s]",
+                                 glade_widget_adaptor_get_name (adaptor),
+                                 glade_widget_get_name (gwidget));
 
-  gtk_widget_translate_coordinates (priv->drag_source, widget,
-                                    alloc.x, alloc.y,
-                                    &x, &y);
-
-  screen = gdk_window_get_screen (gdk_drag_context_get_source_window (context));
-  window = gtk_window_new (GTK_WINDOW_POPUP);
-  gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_DND);
-  gtk_window_set_screen (GTK_WINDOW (window), screen);
-
-  gtk_widget_set_events (window, GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
-  gtk_widget_set_app_paintable (window, TRUE);
-
-  gtk_widget_set_size_request (window, alloc.width, alloc.height);
-  gtk_widget_realize (window);
-
-  surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24, alloc.width, alloc.height);
-  cr = cairo_create (surface);
-
-  gdk_cairo_set_source_window (cr, priv->window, alloc.x - x, alloc.y - y);
-  cairo_paint (cr);
-  cairo_surface_flush (surface);
-  
-  pattern = cairo_pattern_create_for_surface (surface);
-  
-  gdk_window_set_background_pattern (gtk_widget_get_window (window), pattern);
-
-  gtk_window_set_opacity (GTK_WINDOW (window), .5);
-  gtk_drag_set_icon_widget (context, window, priv->drag_x, priv->drag_y);
-
-  cairo_destroy (cr);
-  cairo_pattern_destroy (pattern);
-  cairo_surface_destroy (surface);
-
-  priv->drag_icon = g_object_ref_sink (window);
+  priv->drag_icon = _glade_design_layout_dnd_icon_widget_new (context, icon_name, description);
+  g_object_ref_sink (priv->drag_icon);
+  gtk_drag_set_icon_widget (context, priv->drag_icon, 0, 0);
 }
 
 static void
@@ -1977,6 +2048,7 @@ glade_design_layout_class_init (GladeDesignLayoutClass * klass)
   container_class = GTK_CONTAINER_CLASS (klass);
 
   object_class->constructor = glade_design_layout_constructor;
+  object_class->dispose = glade_design_layout_dispose;
   object_class->finalize = glade_design_layout_finalize;
   object_class->set_property = glade_design_layout_set_property;
   object_class->get_property = glade_design_layout_get_property;
@@ -2170,19 +2242,6 @@ _glade_design_layout_get_hot_point (GladeDesignLayout *layout,
     *y = priv->drag_y;
 }
 
-static gboolean
-widget_is_inside_fixed (GladeWidget *widget)
-{
-  while (widget)
-    {
-      if (GTK_IS_FIXED (glade_widget_get_object (widget)))
-        return TRUE;
-      widget = glade_widget_get_parent (widget);
-    }
-
-  return FALSE;
-}
-
 /*
  * _glade_design_layout_do_event:
  * @layout: A #GladeDesignLayout
@@ -2209,46 +2268,55 @@ _glade_design_layout_do_event (GladeDesignLayout *layout, GdkEvent *event)
 
   mode = glade_project_get_pointer_mode (priv->project);
   glade_design_layout_find_inside_container (widget, &data);
-
-  if (event->type == GDK_BUTTON_PRESS && event->button.button == 1 &&
-      ((event->button.state & GDK_SHIFT_MASK && mode == GLADE_POINTER_SELECT) ||
-       mode == GLADE_POINTER_DRAG_RESIZE))
-    {
-      GObject *source;
-              
-      if (data.gwidget && (source = glade_widget_get_object (data.gwidget)) &&
-          (event->button.state & GDK_SHIFT_MASK || !widget_is_inside_fixed (data.gwidget)))
-        {
-          priv->drag_source = GTK_WIDGET (source);
-
-          gtk_widget_translate_coordinates (widget, priv->drag_source,
-                                            data.x, data.y,
-                                            &priv->drag_x, &priv->drag_y);
-          return TRUE;
-        }
-    }
-  
+ 
   /* Check if we want to enter in margin edit mode */
-  if (event->type == GDK_BUTTON_PRESS && event->button.button == 1 &&
-      mode != GLADE_POINTER_DRAG_RESIZE &&
+  if ((event->type == GDK_BUTTON_PRESS || event->type == GDK_2BUTTON_PRESS)  &&
+      !(event->button.state & GDK_SHIFT_MASK) && /* SHIFT is reserved for Drag&Resize */
+      mode != GLADE_POINTER_DRAG_RESIZE &&       /* This mode is for adaptors implementations */
       (l = glade_project_selection_get (priv->project)) &&
       g_list_next (l) == NULL && GTK_IS_WIDGET (l->data) && 
       gtk_widget_is_ancestor (l->data, widget))
     {
       if (gdl_get_margins_from_pointer (widget, l->data, data.x, data.y))
         {
-          if (priv->selection == NULL)
+          if (event->button.button == 2)
             {
-              gdl_edit_mode_set_selection (layout,
-                                           (event->button.state & GDK_SHIFT_MASK) ? 
-                                           GLADE_POINTER_ALIGN_EDIT : GLADE_POINTER_MARGIN_EDIT,
+              glade_project_set_pointer_mode (priv->project,
+                                              (mode == GLADE_POINTER_MARGIN_EDIT) ?
+                                               GLADE_POINTER_ALIGN_EDIT :
+                                               GLADE_POINTER_MARGIN_EDIT);
+              return TRUE;
+            }
+          else if (event->button.button == 1 && priv->selection == NULL)
+            {
+              gdl_edit_mode_set_selection (layout, GLADE_POINTER_MARGIN_EDIT,
                                            l->data);
               return TRUE;
             }
+
           return FALSE;
         }
     }
 
+  if (event->type == GDK_BUTTON_PRESS && event->button.button == 1 &&
+      mode == GLADE_POINTER_SELECT)
+    {
+      GObject *source;
+
+      if (event->button.state & GDK_SHIFT_MASK)
+        {
+          priv->drag_source = NULL;
+        }
+      else if (data.gwidget && (source = glade_widget_get_object (data.gwidget)))
+        {
+          priv->drag_source = GTK_WIDGET (source);
+
+          gtk_widget_translate_coordinates (widget, priv->drag_source,
+                                            data.x, data.y,
+                                            &priv->drag_x, &priv->drag_y);
+        }
+    }
+
   _glade_design_view_freeze (priv->view);
   
   /* Try the placeholder first */
