@@ -27,7 +27,6 @@
  * SECTION:glade-signal-editor
  * @Title: GladeSignalEditor
  * @Short_Description: An interface to edit signals for a #GladeWidget.
- *W
  */
 
 #include <string.h>
@@ -47,7 +46,7 @@
 #include "glade-project.h"
 #include "glade-cell-renderer-icon.h"
 
-G_DEFINE_TYPE (GladeSignalEditor, glade_signal_editor, GTK_TYPE_VBOX)
+G_DEFINE_TYPE (GladeSignalEditor, glade_signal_editor, GTK_TYPE_BOX)
 
 #define GLADE_SIGNAL_EDITOR_GET_PRIVATE(o)  \
         (G_TYPE_INSTANCE_GET_PRIVATE ((o), GLADE_TYPE_SIGNAL_EDITOR, GladeSignalEditorPrivate))
@@ -630,6 +629,13 @@ glade_signal_editor_new ()
   return signal_editor;
 }
 
+static gint
+find_adaptor_by_name (GladeWidgetAdaptor *adaptor,
+		      const gchar        *name)
+{
+  return g_strcmp0 (glade_widget_adaptor_get_name (adaptor), name);
+}
+
 /**
  * glade_signal_editor_load_widget:
  * @editor: a #GladeSignalEditor
@@ -643,8 +649,10 @@ glade_signal_editor_load_widget (GladeSignalEditor *editor,
 				 GladeWidget *widget)
 {
   GladeSignalEditorPrivate *priv = editor->priv;
+  GList *signals, *l, *adaptors = NULL;
   GtkTreePath *path;
   GtkTreeIter  iter;
+  gboolean valid;
 	
   if (priv->widget != widget)
     {	
@@ -673,6 +681,45 @@ glade_signal_editor_load_widget (GladeSignalEditor *editor,
       gtk_tree_view_expand_row (GTK_TREE_VIEW (priv->signal_tree), path, FALSE);
       gtk_tree_path_free (path);
     }
+
+  /* Collect a list of adaptors which actually have used signals */
+  signals = glade_widget_get_signal_list (widget);
+  for (l = signals; l; l = l->next)
+    {
+      GladeSignal            *signal = l->data;
+      const GladeSignalClass *signal_class;
+      GladeWidgetAdaptor     *adaptor;
+
+      signal_class = glade_signal_get_class (signal);
+      adaptor = glade_signal_class_get_adaptor (signal_class);
+
+      if (!g_list_find (adaptors, adaptor))
+	adaptors = g_list_prepend (adaptors, adaptor);
+    }
+  g_list_free (signals);
+
+  /* Expand any rows which actually contain used signals */
+  valid = gtk_tree_model_iter_children (priv->model, &iter, NULL);
+  while (valid)
+    {
+      gchar *name = NULL;
+
+      gtk_tree_model_get (priv->model, &iter,
+			  GLADE_SIGNAL_COLUMN_NAME, &name,
+			  -1);
+
+      if (g_list_find_custom (adaptors, name, (GCompareFunc)find_adaptor_by_name))
+	{
+	  path = gtk_tree_model_get_path (priv->model, &iter);
+	  gtk_tree_view_expand_row (GTK_TREE_VIEW (priv->signal_tree), path, FALSE);
+	  gtk_tree_path_free (path);
+	}
+
+      g_free (name);
+      valid = gtk_tree_model_iter_next (priv->model, &iter);
+    }
+
+  g_list_free (adaptors);
 }
 
 /**
@@ -1026,10 +1073,13 @@ glade_signal_editor_warning_cell_data_func (GtkTreeViewColumn *column,
 {
   GladeSignal *signal;
   gboolean visible = FALSE;
+  gboolean show_name;
 
   gtk_tree_model_get (model, iter,
 		      GLADE_SIGNAL_COLUMN_SIGNAL, &signal,
+		      GLADE_SIGNAL_COLUMN_SHOW_NAME, &show_name,
 		      -1);
+
   if (signal)
     {
       const gchar* warning = glade_signal_get_support_warning (signal);
@@ -1038,7 +1088,7 @@ glade_signal_editor_warning_cell_data_func (GtkTreeViewColumn *column,
     }
 		
   g_object_set (renderer, 
-		"visible", visible,
+		"visible", (visible && show_name),
 		NULL);
 }
 
@@ -1302,8 +1352,6 @@ glade_signal_editor_init (GladeSignalEditor *self)
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
 				  GTK_POLICY_AUTOMATIC,
 				  GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-				       GTK_SHADOW_IN);
 	
   gtk_container_add (GTK_CONTAINER (scroll), self->priv->signal_tree);
 	
