@@ -25,13 +25,21 @@
 
 #include "glade-activatable-editor.h"
 
+static void glade_activatable_editor_editable_init (GladeEditableIface * iface);
 static void glade_activatable_editor_grab_focus (GtkWidget * widget);
 
 struct _GladeActivatableEditorPrivate {
   GtkWidget *embed;
+
+  GtkWidget *action_name_label;
+  GtkWidget *action_name_editor;
 };
 
-G_DEFINE_TYPE (GladeActivatableEditor, glade_activatable_editor, GLADE_TYPE_EDITOR_SKELETON);
+static GladeEditableIface *parent_editable_iface;
+
+G_DEFINE_TYPE_WITH_CODE (GladeActivatableEditor, glade_activatable_editor, GLADE_TYPE_EDITOR_SKELETON,
+                         G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
+                                                glade_activatable_editor_editable_init));
 
 static void
 glade_activatable_editor_class_init (GladeActivatableEditorClass * klass)
@@ -43,6 +51,8 @@ glade_activatable_editor_class_init (GladeActivatableEditorClass * klass)
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/gladegtk/glade-activatable-editor.ui");
   gtk_widget_class_bind_child (widget_class, GladeActivatableEditorPrivate, embed);
+  gtk_widget_class_bind_child (widget_class, GladeActivatableEditorPrivate, action_name_label);
+  gtk_widget_class_bind_child (widget_class, GladeActivatableEditorPrivate, action_name_editor);
 
   g_type_class_add_private (object_class, sizeof (GladeActivatableEditorPrivate));  
 
@@ -68,6 +78,37 @@ glade_activatable_editor_grab_focus (GtkWidget * widget)
   gtk_widget_grab_focus (activatable_editor->priv->embed);
 }
 
+static void
+glade_activatable_editor_load (GladeEditable *editable,
+			       GladeWidget   *gwidget)
+{
+  GladeActivatableEditor *activatable_editor = GLADE_ACTIVATABLE_EDITOR (editable);
+  GladeActivatableEditorPrivate *priv = activatable_editor->priv;
+  GtkWidget *widget;
+
+  /* Chain up to default implementation */
+  parent_editable_iface->load (editable, gwidget);
+
+  if (gwidget)
+    {
+      gboolean actionable;
+
+      widget = (GtkWidget *)glade_widget_get_object (gwidget);
+      actionable = GTK_IS_ACTIONABLE (widget);
+
+      gtk_widget_set_visible (priv->action_name_label, actionable);
+      gtk_widget_set_visible (priv->action_name_editor, actionable);
+    }
+}
+
+static void
+glade_activatable_editor_editable_init (GladeEditableIface * iface)
+{
+  parent_editable_iface = g_type_interface_peek_parent (iface);
+
+  iface->load = glade_activatable_editor_load;
+}
+
 GtkWidget *
 glade_activatable_editor_new (GladeWidgetAdaptor * adaptor,
                               GladeEditable * embed)
